@@ -579,7 +579,7 @@ void WritePolarizationForLinearPols(casacore::MeasurementSet& ms, bool flagRow =
 	flagRowCol.put(rowIndex, flagRow);
 }
 
-void actionCombine(const std::string outFilename, const std::vector<std::string> inFilenames)
+void actionCombine(const std::string& outFilename, const std::vector<std::string>& inFilenames)
 {
 	if(!inFilenames.empty())
 	{
@@ -765,8 +765,7 @@ int main(int argc, char *argv[])
 						"\tRFIRatio, Count, Mean, SumP2, DCount, DMean, DSumP2.\n"
 						"The subtables that will be updated are:\n"
 						"\tQUALITY_KIND_NAME, QUALITY_TIME_STATISTIC,\n"
-						"\tQUALITY_FREQUENCY_STATISTIC and QUALITY_BASELINE_STATISTIC.\n\n"
-						"-c will use the CORRECTED_DATA column.\n";
+						"\tQUALITY_FREQUENCY_STATISTIC and QUALITY_BASELINE_STATISTIC.\n\n";
 				}
 				else if(helpAction == "summarize")
 				{
@@ -840,7 +839,7 @@ int main(int argc, char *argv[])
 				int argi = 2;
 				bool histograms = false, timeFrequency = false;
 				const char* dataColumnName = "DATA";
-				while(argv[argi][0] == '-' && argi < argc)
+				while(argi < argc && argv[argi][0] == '-')
 				{
 					std::string p = &argv[argi][1];
 					if(p == "h")
