@@ -13,23 +13,18 @@ namespace rfiStrategy {
 		SVDMitigater mitigater;
 		mitigater.Initialize(artifacts.ContaminatedData());
 		mitigater.SetRemoveCount(_singularValueCount);
-		for(size_t i=0;i<mitigater.TaskCount();++i)
-		{
-			mitigater.PerformFit(i);
-			listener.OnProgress(*this, i+1, mitigater.TaskCount());
-		}
+		mitigater.PerformFit();
+		listener.OnProgress(*this, 1, 1);
 
 		TimeFrequencyData newRevisedData = mitigater.Background();
 		newRevisedData.SetMask(artifacts.RevisedData());
 
-		TimeFrequencyData *contaminatedData =
-			TimeFrequencyData::CreateTFDataFromDiff(artifacts.ContaminatedData(), newRevisedData);
-		contaminatedData->SetMask(artifacts.ContaminatedData());
+		TimeFrequencyData contaminatedData =
+			TimeFrequencyData::MakeFromDiff(artifacts.ContaminatedData(), newRevisedData);
+		contaminatedData.SetMask(artifacts.ContaminatedData());
 
 		artifacts.SetRevisedData(newRevisedData);
-		artifacts.SetContaminatedData(*contaminatedData);
-
-		delete contaminatedData;
+		artifacts.SetContaminatedData(contaminatedData);
 	}
 
 } // namespace rfiStrategy
