@@ -4,20 +4,16 @@
 
 #include "../actions/absthresholdaction.h"
 #include "../actions/action.h"
-#include "../actions/addstatisticsaction.h"
 #include "../actions/baselineselectionaction.h"
 #include "../actions/calibratepassbandaction.h"
 #include "../actions/changeresolutionaction.h"
 #include "../actions/combineflagresultsaction.h"
 #include "../actions/cutareaaction.h"
-#include "../actions/directionalcleanaction.h"
-#include "../actions/directionprofileaction.h"
 #include "../actions/eigenvalueverticalaction.h"
 #include "../actions/foreachbaselineaction.h"
 #include "../actions/foreachcomplexcomponentaction.h"
 #include "../actions/foreachmsaction.h"
 #include "../actions/foreachpolarisationaction.h"
-#include "../actions/fouriertransformaction.h"
 #include "../actions/frequencyconvolutionaction.h"
 #include "../actions/frequencyselectionaction.h"
 #include "../actions/fringestopaction.h"
@@ -36,7 +32,6 @@
 #include "../actions/sumthresholdaction.h"
 #include "../actions/timeconvolutionaction.h"
 #include "../actions/timeselectionaction.h"
-#include "../actions/uvprojectaction.h"
 #include "../actions/writedataaction.h"
 #include "../actions/writeflagsaction.h"
 
@@ -62,20 +57,20 @@ StrategyReader::~StrategyReader()
 		xmlCleanupParser();
 }
 
-Strategy *StrategyReader::CreateStrategyFromFile(const std::string &filename)
+std::unique_ptr<Strategy> StrategyReader::CreateStrategyFromFile(const std::string &filename)
 {
 	_xmlDocument = xmlReadFile(filename.c_str(), NULL, 0);
 	if (_xmlDocument == NULL)
 		throw StrategyReaderError("Failed to read file");
 
 	xmlNode *rootElement = xmlDocGetRootElement(_xmlDocument);
-	Strategy *strategy = 0;
+	std::unique_ptr<Strategy> strategy;
 
 	for (xmlNode *curNode=rootElement; curNode!=NULL; curNode=curNode->next)
 	{
 		if(curNode->type == XML_ELEMENT_NODE)
 		{
-			if(strategy != 0)
+			if(strategy != nullptr)
 				throw StrategyReaderError("Multiple root elements found.");
 			if(std::string((const char *) curNode->name) != "rfi-strategy")
 				throw StrategyReaderError("Invalid structure in xml file: no rfi-strategy root node found. Maybe this is not an rfi strategy?");
@@ -104,7 +99,7 @@ Strategy *StrategyReader::CreateStrategyFromFile(const std::string &filename)
 			strategy = parseRootChildren(curNode);
 		}
 	}
-	if(strategy == 0)
+	if(strategy == nullptr)
 		throw StrategyReaderError("Could not find root element in file.");
 
 	xmlFreeDoc(_xmlDocument);
@@ -112,31 +107,31 @@ Strategy *StrategyReader::CreateStrategyFromFile(const std::string &filename)
 	return strategy;
 }
 
-Strategy *StrategyReader::parseRootChildren(xmlNode *rootNode)
+std::unique_ptr<Strategy> StrategyReader::parseRootChildren(xmlNode *rootNode)
 {
-	Strategy *strategy = 0;
+	std::unique_ptr<Strategy> strategy;
 	for (xmlNode *curNode=rootNode->children; curNode!=NULL; curNode=curNode->next) {
 		if(curNode->type == XML_ELEMENT_NODE)
 		{
-			if(strategy != 0)
+			if(strategy != nullptr)
 				throw StrategyReaderError("More than one root element in file!");
-			strategy = dynamic_cast<Strategy*>(parseAction(curNode));
-			if(strategy == 0)
+			strategy = std::unique_ptr<Strategy>(dynamic_cast<Strategy*>(parseAction(curNode)));
+			if(strategy == nullptr)
 				throw StrategyReaderError("Root element was not a strategy!");
 		}
 	}
-	if(strategy == 0)
+	if(strategy == nullptr)
 		throw StrategyReaderError("Root element not found.");
 
 	return strategy;
 }
 
-Action *StrategyReader::parseChild(xmlNode *node)
+std::unique_ptr<Action> StrategyReader::parseChild(xmlNode *node)
 {
 	if (node->type == XML_ELEMENT_NODE) {
 		std::string name((const char*) node->name);
 		if(name == "action")
-			return parseAction(node);
+			return std::unique_ptr<Action>(parseAction(node));
 	}
 	throw StrategyReaderError("Invalid structure in xml file: an action was expected");
 }
@@ -186,9 +181,13 @@ xmlNode *StrategyReader::getTextNode(xmlNode *node, const char *subNodeName, boo
 			}
 		}
 	}
-	std::ostringstream str;
-	str << "Error occured in reading xml file: could not find value node \"" << subNodeName << '\"';
-	throw StrategyReaderError(str.str());
+	if(allowEmpty)
+		return 0;
+	else {
+		std::ostringstream str;
+		str << "Error occured in reading xml file: could not find value node \"" << subNodeName << '\"';
+		throw StrategyReaderError(str.str());
+	}
 }
 
 int StrategyReader::getInt(xmlNode *node, const char *name) const 
@@ -203,6 +202,15 @@ double StrategyReader::getDouble(xmlNode *node, const char *name) const
 	return NumberParser::ToDouble((const char *) valNode->content);
 }
 
+double StrategyReader::getDoubleOr(xmlNode *node, const char *name, double alternative) const 
+{
+	xmlNode *valNode = getTextNode(node, name, true);
+	if(valNode == 0)
+		return alternative;
+	else
+		return NumberParser::ToDouble((const char *) valNode->content);
+}
+
 std::string StrategyReader::getString(xmlNode *node, const char *name) const 
 {
 	xmlNode *valNode = getTextNode(node, name, true);
@@ -221,8 +229,6 @@ Action *StrategyReader::parseAction(xmlNode *node)
 	std::string typeStr((const char*) typeCh);
 	if(typeStr == "AbsThresholdAction")
 		newAction = parseAbsThresholdAction(node);
-	else if(typeStr == "AddStatisticsAction")
-		newAction = parseAddStatistics(node);
 	else if(typeStr == "BaselineSelectionAction")
 		newAction = parseBaselineSelectionAction(node);
 	else if(typeStr == "CalibratePassbandAction")
@@ -233,10 +239,6 @@ Action *StrategyReader::parseAction(xmlNode *node)
 		newAction = parseCombineFlagResults(node);
 	else if(typeStr == "CutAreaAction")
 		newAction = parseCutAreaAction(node);
-	else if(typeStr == "DirectionalCleanAction")
-		newAction = parseDirectionalCleanAction(node);
-	else if(typeStr == "DirectionProfileAction")
-		newAction = parseDirectionProfileAction(node);
 	else if(typeStr == "EigenValueVerticalAction")
 	  newAction = parseEigenValueVerticalAction(node);
 	else if(typeStr == "ForEachBaselineAction")
@@ -247,8 +249,6 @@ Action *StrategyReader::parseAction(xmlNode *node)
 		newAction = parseForEachMSAction(node);
 	else if(typeStr == "ForEachPolarisationBlock")
 		newAction = parseForEachPolarisationBlock(node);
-	else if(typeStr == "FourierTransformAction")
-		newAction = parseFourierTransformAction(node);
 	else if(typeStr == "FrequencyConvolutionAction")
 		newAction = parseFrequencyConvolutionAction(node);
 	else if(typeStr == "FrequencySelectionAction")
@@ -285,8 +285,6 @@ Action *StrategyReader::parseAction(xmlNode *node)
 		newAction = parseTimeConvolutionAction(node);
 	else if(typeStr == "TimeSelectionAction")
 		newAction = parseTimeSelectionAction(node);
-	else if(typeStr == "UVProjectAction")
-		newAction = parseUVProjectAction(node);
 	else if(typeStr == "WriteDataAction")
 		newAction = parseWriteDataAction(node);
 	else if(typeStr == "WriteFlagsAction")
@@ -308,6 +306,7 @@ Action *StrategyReader::parseAbsThresholdAction(xmlNode *node)
 	return newAction;
 }
 
+/*
 Action *StrategyReader::parseAddStatistics(xmlNode *node)
 {
 	AddStatisticsAction *newAction = new AddStatisticsAction();
@@ -317,7 +316,7 @@ Action *StrategyReader::parseAddStatistics(xmlNode *node)
 	newAction->SetPerformClassification(getBool(node, "perform-classification"));
 	newAction->SetWriteImmediately(getBool(node, "write-immediately"));
 	return newAction;
-}
+}*/
 
 Action *StrategyReader::parseBaselineSelectionAction(xmlNode *node)
 {
@@ -367,24 +366,6 @@ Action *StrategyReader::parseCutAreaAction(xmlNode *node)
 	return newAction;
 }
 
-Action *StrategyReader::parseDirectionalCleanAction(xmlNode *node)
-{
-	DirectionalCleanAction *newAction = new DirectionalCleanAction();
-	newAction->SetLimitingDistance(getDouble(node, "limiting-distance"));
-	newAction->SetChannelConvolutionSize(getInt(node, "channel-convolution-size"));
-	newAction->SetAttenuationOfCenter(getDouble(node, "attenuation-of-center"));
-	newAction->SetMakePlot(getBool(node, "make-plot"));
-	return newAction;
-}
-
-Action *StrategyReader::parseDirectionProfileAction(xmlNode *node)
-{
-	DirectionProfileAction *newAction = new DirectionProfileAction();
-	newAction->SetAxis((enum DirectionProfileAction::Axis) getInt(node, "axis"));
-	newAction->SetProfileAction((enum DirectionProfileAction::ProfileAction) getInt(node, "profile-action"));
-	return newAction;
-}
-
 Action *StrategyReader::parseEigenValueVerticalAction(xmlNode *)
 {
   EigenValueVerticalAction *newAction = new EigenValueVerticalAction();
@@ -497,12 +478,6 @@ Action *StrategyReader::parseForEachPolarisationBlock(xmlNode *node)
 	return newAction;
 }
 
-Action *StrategyReader::parseFourierTransformAction(xmlNode *)
-{
-	FourierTransformAction *newAction = new FourierTransformAction();
-	return newAction;
-}
-
 Action *StrategyReader::parseFrequencyConvolutionAction(xmlNode *node)
 {
 	FrequencyConvolutionAction *newAction = new FrequencyConvolutionAction();
@@ -606,8 +581,9 @@ class Action *StrategyReader::parseStatisticalFlagAction(xmlNode *node)
 	StatisticalFlagAction *newAction = new StatisticalFlagAction();
 	newAction->SetEnlargeFrequencySize(getInt(node, "enlarge-frequency-size"));
 	newAction->SetEnlargeTimeSize(getInt(node, "enlarge-time-size"));
-	newAction->SetMaxContaminatedFrequenciesRatio(getDouble(node, "max-contaminated-frequencies-ratio"));
-	newAction->SetMaxContaminatedTimesRatio(getDouble(node, "max-contaminated-times-ratio"));
+	newAction->SetMinAvailableFrequenciesRatio(getDoubleOr(node, "min-available-frequencies-ratio", 0.0));
+	newAction->SetMinAvailableTimesRatio(getDoubleOr(node, "min-available-times-ratio", 0.0));
+	newAction->SetMinAvailableTFRatio(getDoubleOr(node, "min-available-tf-ratio", 0.0));
 	newAction->SetMinimumGoodFrequencyRatio(getDouble(node, "minimum-good-frequency-ratio"));
 	newAction->SetMinimumGoodTimeRatio(getDouble(node, "minimum-good-time-ratio"));
 	return newAction;
@@ -649,18 +625,6 @@ class Action *StrategyReader::parseTimeSelectionAction(xmlNode *node)
 	return newAction;
 }
 
-class Action *StrategyReader::parseUVProjectAction(xmlNode *node)
-{
-	UVProjectAction *newAction = new UVProjectAction();
-	newAction->SetDirectionRad(getDouble(node, "direction-rad"));
-	newAction->SetEtaParameter(getDouble(node, "eta-parameter"));
-	newAction->SetDestResolutionFactor(getDouble(node, "dest-resolution-factor"));
-	newAction->SetReverse(getBool(node, "reverse"));
-	newAction->SetOnRevised(getBool(node, "on-revised"));
-	newAction->SetOnContaminated(getBool(node, "on-contaminated"));
-	return newAction;
-}
-
 class Action *StrategyReader::parseWriteDataAction(xmlNode *)
 {
 	WriteDataAction *newAction = new WriteDataAction();
