@@ -4,9 +4,9 @@
 #include "../testingtools/asserter.h"
 #include "../testingtools/unittest.h"
 
-#include "../../strategy/algorithms/mitigationtester.h"
+#include "../../strategy/algorithms/combinatorialthresholder.h"
+#include "../../strategy/algorithms/testsetgenerator.h"
 #include "../../strategy/algorithms/siroperator.h"
-#include "../../strategy/algorithms/thresholdmitigater.h"
 
 #include "../../strategy/actions/baselineselectionaction.h"
 #include "../../strategy/actions/changeresolutionaction.h"
@@ -30,7 +30,7 @@
 
 #include "../../structures/timefrequencydata.h"
 
-#include "../../util/aologger.h"
+#include "../../util/logger.h"
 
 class DefaultStrategySpeedTest : public UnitTest {
 	public:
@@ -52,7 +52,7 @@ class DefaultStrategySpeedTest : public UnitTest {
 #endif
 		}
 		
-		DefaultStrategySpeedTest(const std::string &) : UnitTest("Default strategy speed test")
+		explicit DefaultStrategySpeedTest(const std::string &) : UnitTest("Default strategy speed test")
 		{
 			AddTest(TimeSumThresholdN(), "Timing varying SumThreshold method");
 		}
@@ -105,16 +105,16 @@ inline void DefaultStrategySpeedTest::prepareStrategy(rfiStrategy::ArtifactSet &
 	const unsigned
 		width = 10000,
 		height = 256;
-	Mask2DPtr rfi = Mask2D::CreateUnsetMaskPtr(width, height);
+	Mask2D rfi = Mask2D::MakeUnsetMask(width, height);
 	Image2DPtr
-		xxReal = MitigationTester::CreateTestSet(26, rfi, width, height),
-		xxImag = MitigationTester::CreateTestSet(26, rfi, width, height),
-		xyReal = MitigationTester::CreateTestSet(26, rfi, width, height),
-		xyImag = MitigationTester::CreateTestSet(26, rfi, width, height),
-		yxReal = MitigationTester::CreateTestSet(26, rfi, width, height),
-		yxImag = MitigationTester::CreateTestSet(26, rfi, width, height),
-		yyReal = MitigationTester::CreateTestSet(26, rfi, width, height),
-		yyImag = MitigationTester::CreateTestSet(26, rfi, width, height);
+		xxReal = Image2D::MakePtr(TestSetGenerator::MakeTestSet(26, rfi, width, height)),
+		xxImag = Image2D::MakePtr(TestSetGenerator::MakeTestSet(26, rfi, width, height)),
+		xyReal = Image2D::MakePtr(TestSetGenerator::MakeTestSet(26, rfi, width, height)),
+		xyImag = Image2D::MakePtr(TestSetGenerator::MakeTestSet(26, rfi, width, height)),
+		yxReal = Image2D::MakePtr(TestSetGenerator::MakeTestSet(26, rfi, width, height)),
+		yxImag = Image2D::MakePtr(TestSetGenerator::MakeTestSet(26, rfi, width, height)),
+		yyReal = Image2D::MakePtr(TestSetGenerator::MakeTestSet(26, rfi, width, height)),
+		yyImag = Image2D::MakePtr(TestSetGenerator::MakeTestSet(26, rfi, width, height));
 	TimeFrequencyData data = TimeFrequencyData::FromLinear(
 		xxReal, xxImag, xyReal, xyImag,
 		yxReal, yxImag, yyReal, yyImag);
@@ -127,218 +127,220 @@ inline void DefaultStrategySpeedTest::prepareStrategy(rfiStrategy::ArtifactSet &
 inline void DefaultStrategySpeedTest::TimeStrategy::operator()()
 {
 	rfiStrategy::ArtifactSet artifacts(0);
-	rfiStrategy::Strategy *strategy = rfiStrategy::DefaultStrategy::CreateStrategy(
+	std::unique_ptr<rfiStrategy::Strategy> strategy = rfiStrategy::DefaultStrategy::CreateStrategy(
 		rfiStrategy::DefaultStrategy::GENERIC_TELESCOPE, rfiStrategy::DefaultStrategy::FLAG_NONE
 	);
 	prepareStrategy(artifacts);
 	DummyProgressListener progressListener;
 	Stopwatch watch(true);
 	strategy->Perform(artifacts, progressListener);
-	AOLogger::Info << "Default strategy took: " << watch.ToString() << '\n';
-	delete strategy;
+	Logger::Info << "Default strategy took: " << watch.ToString() << '\n';
 }
 
 inline void DefaultStrategySpeedTest::TimeSlidingWindowFit::operator()()
 {
 	rfiStrategy::ArtifactSet artifacts(0);
-	rfiStrategy::ActionBlock *current;
+	rfiStrategy::ActionBlock *current, *scratch;
 
 	rfiStrategy::Strategy strategy;
 	
-	rfiStrategy::ForEachPolarisationBlock *fepBlock = new rfiStrategy::ForEachPolarisationBlock();
-	strategy.Add(fepBlock);
-	current = fepBlock;
+	std::unique_ptr<rfiStrategy::ForEachPolarisationBlock> fepBlock(new rfiStrategy::ForEachPolarisationBlock());
+	current = fepBlock.get();
+	strategy.Add(std::move(fepBlock));
 
-	rfiStrategy::ForEachComplexComponentAction *focAction = new rfiStrategy::ForEachComplexComponentAction();
+	std::unique_ptr<rfiStrategy::ForEachComplexComponentAction> focAction(new rfiStrategy::ForEachComplexComponentAction());
 	focAction->SetOnAmplitude(true);
 	focAction->SetOnImaginary(false);
 	focAction->SetOnReal(false);
 	focAction->SetOnPhase(false);
 	focAction->SetRestoreFromAmplitude(false);
-	current->Add(focAction);
-	current = focAction;
+	scratch = focAction.get();
+	current->Add(std::move(focAction));
+	current = scratch;
 
-	rfiStrategy::IterationBlock *iteration = new rfiStrategy::IterationBlock();
+	std::unique_ptr<rfiStrategy::IterationBlock> iteration(new rfiStrategy::IterationBlock());
 	iteration->SetIterationCount(2);
 	iteration->SetSensitivityStart(4.0);
-	current->Add(iteration);
-	current = iteration;
+	scratch = iteration.get();
+	current->Add(std::move(iteration));
+	current = scratch;
 	
-	rfiStrategy::ChangeResolutionAction *changeResAction2 = new rfiStrategy::ChangeResolutionAction();
+	std::unique_ptr<rfiStrategy::ChangeResolutionAction> changeResAction2(new rfiStrategy::ChangeResolutionAction());
 	changeResAction2->SetTimeDecreaseFactor(3);
 	changeResAction2->SetFrequencyDecreaseFactor(3);
 
-	rfiStrategy::SlidingWindowFitAction *swfAction2 = new rfiStrategy::SlidingWindowFitAction();
+	std::unique_ptr<rfiStrategy::SlidingWindowFitAction> swfAction2(new rfiStrategy::SlidingWindowFitAction());
 	swfAction2->Parameters().timeDirectionKernelSize = 2.5;
 	swfAction2->Parameters().timeDirectionWindowSize = 10;
 	swfAction2->Parameters().frequencyDirectionKernelSize = 5.0;
 	swfAction2->Parameters().frequencyDirectionWindowSize = 15;
-	changeResAction2->Add(swfAction2);
+	changeResAction2->Add(std::move(swfAction2));
 
-	current->Add(changeResAction2);
+	current->Add(std::move(changeResAction2));
 	
 	prepareStrategy(artifacts);
 	DummyProgressListener progressListener;
 	Stopwatch watch(true);
 	strategy.Perform(artifacts, progressListener);
-	AOLogger::Info << "Sliding window fit took (loop + fit): " << watch.ToString() << '\n';
+	Logger::Info << "Sliding window fit took (loop + fit): " << watch.ToString() << '\n';
 }
 
 inline void DefaultStrategySpeedTest::TimeHighPassFilter::operator()()
 {
 	rfiStrategy::ArtifactSet artifacts(0);
-	rfiStrategy::ActionBlock *current;
+	rfiStrategy::ActionBlock *current, *scratch;
 
 	rfiStrategy::Strategy strategy;
 	
-	rfiStrategy::ForEachPolarisationBlock *fepBlock = new rfiStrategy::ForEachPolarisationBlock();
-	strategy.Add(fepBlock);
-	current = fepBlock;
+	std::unique_ptr<rfiStrategy::ForEachPolarisationBlock> fepBlock(new rfiStrategy::ForEachPolarisationBlock());
+	scratch = fepBlock.get();
+	strategy.Add(std::move(fepBlock));
+	current = scratch;
 
-	rfiStrategy::ForEachComplexComponentAction *focAction = new rfiStrategy::ForEachComplexComponentAction();
+	std::unique_ptr<rfiStrategy::ForEachComplexComponentAction> focAction(new rfiStrategy::ForEachComplexComponentAction());
 	focAction->SetOnAmplitude(true);
 	focAction->SetOnImaginary(false);
 	focAction->SetOnReal(false);
 	focAction->SetOnPhase(false);
 	focAction->SetRestoreFromAmplitude(false);
-	current->Add(focAction);
-	current = focAction;
+	scratch = focAction.get();
+	current->Add(std::move(focAction));
+	current = scratch;
 
-	rfiStrategy::IterationBlock *iteration = new rfiStrategy::IterationBlock();
+	std::unique_ptr<rfiStrategy::IterationBlock> iteration(new rfiStrategy::IterationBlock());
 	iteration->SetIterationCount(2);
 	iteration->SetSensitivityStart(4.0);
-	current->Add(iteration);
-	current = iteration;
+	scratch = iteration.get();
+	current->Add(std::move(iteration));
+	current = scratch;
 	
-	rfiStrategy::ChangeResolutionAction *changeResAction2 = new rfiStrategy::ChangeResolutionAction();
+	std::unique_ptr<rfiStrategy::ChangeResolutionAction> changeResAction2(new rfiStrategy::ChangeResolutionAction());
 	changeResAction2->SetTimeDecreaseFactor(3);
 	changeResAction2->SetFrequencyDecreaseFactor(3);
 
-	rfiStrategy::HighPassFilterAction *hpAction = new rfiStrategy::HighPassFilterAction();
+	std::unique_ptr<rfiStrategy::HighPassFilterAction> hpAction(new rfiStrategy::HighPassFilterAction());
 	hpAction->SetHKernelSigmaSq(2.5);
 	hpAction->SetWindowWidth(10);
 	hpAction->SetVKernelSigmaSq(5.0);
 	hpAction->SetWindowHeight(15);
 	hpAction->SetMode(rfiStrategy::HighPassFilterAction::StoreRevised);
-	changeResAction2->Add(hpAction);
+	changeResAction2->Add(std::move(hpAction));
 
-	current->Add(changeResAction2);
+	current->Add(std::move(changeResAction2));
 	
 	prepareStrategy(artifacts);
 	DummyProgressListener progressListener;
 	Stopwatch watch(true);
 	strategy.Perform(artifacts, progressListener);
-	AOLogger::Info << "High-pass filter took (loop + fit): " << watch.ToString() << '\n';
+	Logger::Info << "High-pass filter took (loop + fit): " << watch.ToString() << '\n';
 }
 
 inline void DefaultStrategySpeedTest::TimeLoop::operator()()
 {
 	rfiStrategy::ArtifactSet artifacts(0);
-	rfiStrategy::ActionBlock *current;
+	rfiStrategy::ActionBlock *current, *scratch;
 
 	rfiStrategy::Strategy strategy;
 	
-	rfiStrategy::ForEachPolarisationBlock *fepBlock = new rfiStrategy::ForEachPolarisationBlock();
-	strategy.Add(fepBlock);
-	current = fepBlock;
+	std::unique_ptr<rfiStrategy::ForEachPolarisationBlock> fepBlock(new rfiStrategy::ForEachPolarisationBlock());
+	scratch = fepBlock.get();
+	strategy.Add(std::move(fepBlock));
+	current = scratch;
 
-	rfiStrategy::ForEachComplexComponentAction *focAction = new rfiStrategy::ForEachComplexComponentAction();
+	std::unique_ptr<rfiStrategy::ForEachComplexComponentAction> focAction(new rfiStrategy::ForEachComplexComponentAction());
 	focAction->SetOnAmplitude(true);
 	focAction->SetOnImaginary(false);
 	focAction->SetOnReal(false);
 	focAction->SetOnPhase(false);
 	focAction->SetRestoreFromAmplitude(false);
-	current->Add(focAction);
-	current = focAction;
+	scratch = focAction.get();
+	current->Add(std::move(focAction));
+	current = scratch;
 
-	rfiStrategy::IterationBlock *iteration = new rfiStrategy::IterationBlock();
+	std::unique_ptr<rfiStrategy::IterationBlock> iteration(new rfiStrategy::IterationBlock());
 	iteration->SetIterationCount(2);
 	iteration->SetSensitivityStart(4.0);
-	current->Add(iteration);
-	current = iteration;
+	scratch = iteration.get();
+	current->Add(std::move(iteration));
+	current = scratch;
 	
-	rfiStrategy::ChangeResolutionAction *changeResAction2 = new rfiStrategy::ChangeResolutionAction();
+	std::unique_ptr<rfiStrategy::ChangeResolutionAction> changeResAction2(new rfiStrategy::ChangeResolutionAction());
 	changeResAction2->SetTimeDecreaseFactor(3);
 	changeResAction2->SetFrequencyDecreaseFactor(3);
-	current->Add(changeResAction2);
+	current->Add(std::move(changeResAction2));
 	
 	prepareStrategy(artifacts);
 	DummyProgressListener progressListener;
 	Stopwatch watch(true);
 	strategy.Perform(artifacts, progressListener);
-	AOLogger::Info << "Loop took: " << watch.ToString() << '\n';
+	Logger::Info << "Loop took: " << watch.ToString() << '\n';
 }
 
 inline void DefaultStrategySpeedTest::TimeLoopUntilAmplitude::operator()()
 {
 	rfiStrategy::ArtifactSet artifacts(0);
-	rfiStrategy::ActionBlock *current;
 
 	rfiStrategy::Strategy strategy;
 	
-	rfiStrategy::ForEachPolarisationBlock *fepBlock = new rfiStrategy::ForEachPolarisationBlock();
-	strategy.Add(fepBlock);
-	current = fepBlock;
-
-	rfiStrategy::ForEachComplexComponentAction *focAction = new rfiStrategy::ForEachComplexComponentAction();
+	std::unique_ptr<rfiStrategy::ForEachPolarisationBlock> fepBlock(new rfiStrategy::ForEachPolarisationBlock());
+	
+	std::unique_ptr<rfiStrategy::ForEachComplexComponentAction> focAction(new rfiStrategy::ForEachComplexComponentAction());
 	focAction->SetOnAmplitude(true);
 	focAction->SetOnImaginary(false);
 	focAction->SetOnReal(false);
 	focAction->SetOnPhase(false);
 	focAction->SetRestoreFromAmplitude(false);
-	current->Add(focAction);
+	fepBlock->Add(std::move(focAction));
+
+	strategy.Add(std::move(fepBlock));
 
 	prepareStrategy(artifacts);
 	DummyProgressListener progressListener;
 	Stopwatch watch(true);
 	strategy.Perform(artifacts, progressListener);
-	AOLogger::Info << "Loop took: " << watch.ToString() << '\n';
+	Logger::Info << "Loop took: " << watch.ToString() << '\n';
 }
 
 inline void DefaultStrategySpeedTest::TimeSumThreshold::operator()()
 {
 	rfiStrategy::ArtifactSet artifacts(0);
-	rfiStrategy::ActionBlock *current;
 
 	rfiStrategy::Strategy strategy;
 	
-	rfiStrategy::ForEachPolarisationBlock *fepBlock = new rfiStrategy::ForEachPolarisationBlock();
-	strategy.Add(fepBlock);
-	current = fepBlock;
+	std::unique_ptr<rfiStrategy::ForEachPolarisationBlock> fepBlock(new rfiStrategy::ForEachPolarisationBlock());
 
-	rfiStrategy::ForEachComplexComponentAction *focAction = new rfiStrategy::ForEachComplexComponentAction();
+	std::unique_ptr<rfiStrategy::ForEachComplexComponentAction> focAction(new rfiStrategy::ForEachComplexComponentAction());
 	focAction->SetOnAmplitude(true);
 	focAction->SetOnImaginary(false);
 	focAction->SetOnReal(false);
 	focAction->SetOnPhase(false);
 	focAction->SetRestoreFromAmplitude(false);
-	current->Add(focAction);
-	current = focAction;
 
-	rfiStrategy::IterationBlock *iteration = new rfiStrategy::IterationBlock();
+	std::unique_ptr<rfiStrategy::IterationBlock> iteration(new rfiStrategy::IterationBlock());
 	iteration->SetIterationCount(2);
 	iteration->SetSensitivityStart(4.0);
-	current->Add(iteration);
-	current = iteration;
 	
-	rfiStrategy::SumThresholdAction *t2 = new rfiStrategy::SumThresholdAction();
+	std::unique_ptr<rfiStrategy::SumThresholdAction> t2(new rfiStrategy::SumThresholdAction());
 	t2->SetBaseSensitivity(1.0);
-	current->Add(t2);
+	iteration->Add(std::move(t2));
 		
-	rfiStrategy::ChangeResolutionAction *changeResAction2 = new rfiStrategy::ChangeResolutionAction();
+	std::unique_ptr<rfiStrategy::ChangeResolutionAction> changeResAction2(new rfiStrategy::ChangeResolutionAction());
 	changeResAction2->SetTimeDecreaseFactor(3);
 	changeResAction2->SetFrequencyDecreaseFactor(3);
-	current->Add(changeResAction2);
+	iteration->Add(std::move(changeResAction2));
 	
-	current = focAction;
-	rfiStrategy::SumThresholdAction *t3 = new rfiStrategy::SumThresholdAction();
-	current->Add(t3);
+	std::unique_ptr<rfiStrategy::SumThresholdAction> t3(new rfiStrategy::SumThresholdAction());
+	focAction->Add(std::move(t3));
+	
+	focAction->Add(std::move(iteration));
+	fepBlock->Add(std::move(focAction));
+	strategy.Add(std::move(fepBlock));
 		
 	prepareStrategy(artifacts);
 	DummyProgressListener progressListener;
 	Stopwatch watch(true);
 	strategy.Perform(artifacts, progressListener);
-	AOLogger::Info << "Sum threshold took (loop + threshold): " << watch.ToString() << '\n';
+	Logger::Info << "Sum threshold took (loop + threshold): " << watch.ToString() << '\n';
 }
 
 inline void DefaultStrategySpeedTest::TimeSumThresholdN::operator()()
@@ -350,8 +352,8 @@ inline void DefaultStrategySpeedTest::TimeSumThresholdN::operator()()
 	config.InitializeLengthsDefault(9);
 	num_t stddev = artifacts.OriginalData().GetSingleImage()->GetStdDev();
 	num_t mode = artifacts.OriginalData().GetSingleImage()->GetMode();
-	AOLogger::Info << "Stddev: " << stddev << '\n';
-	AOLogger::Info << "Mode: " << mode << '\n';
+	Logger::Info << "Stddev: " << stddev << '\n';
+	Logger::Info << "Mode: " << mode << '\n';
 	config.InitializeThresholdsFromFirstThreshold(6.0 * stddev, ThresholdConfig::Rayleigh);
 	for(unsigned i=0;i<9;++i)
 	{
@@ -359,28 +361,28 @@ inline void DefaultStrategySpeedTest::TimeSumThresholdN::operator()()
 		const double threshold = config.GetHorizontalThreshold(i);
 		Image2DCPtr input = artifacts.OriginalData().GetSingleImage();
 		
-		Mask2DPtr maskA = Mask2D::CreateCopy(artifacts.OriginalData().GetSingleMask());
+		Mask2DPtr maskA(new Mask2D(*artifacts.OriginalData().GetSingleMask()));
 		Stopwatch watchA(true);
-		ThresholdMitigater::HorizontalSumThresholdLargeReference(input, maskA, length, threshold);
-		AOLogger::Info << "Horizontal, length " << length << ": " << watchA.ToString() << '\n';
+		CombinatorialThresholder::HorizontalSumThresholdLargeReference(input.get(), maskA.get(), length, threshold);
+		Logger::Info << "Horizontal, length " << length << ": " << watchA.ToString() << '\n';
 		
 #ifdef __SSE__
-		Mask2DPtr maskC = Mask2D::CreateCopy(artifacts.OriginalData().GetSingleMask());
+		Mask2DPtr maskC(new Mask2D(*artifacts.OriginalData().GetSingleMask()));
 		Stopwatch watchC(true);
-		ThresholdMitigater::HorizontalSumThresholdLargeSSE(input, maskC, length, threshold);
-		AOLogger::Info << "Horizontal SSE, length " << length << ": " << watchC.ToString() << '\n';
+		CombinatorialThresholder::HorizontalSumThresholdLargeSSE(input.get(), maskC.get(), length, threshold);
+		Logger::Info << "Horizontal SSE, length " << length << ": " << watchC.ToString() << '\n';
 #endif
 		
-		Mask2DPtr maskB = Mask2D::CreateCopy(artifacts.OriginalData().GetSingleMask());
+		Mask2DPtr maskB(new Mask2D(*artifacts.OriginalData().GetSingleMask()));
 		Stopwatch watchB(true);
-		ThresholdMitigater::VerticalSumThresholdLargeReference(input, maskB, length, threshold);
-		AOLogger::Info << "Vertical, length " << length << ": " << watchB.ToString() << '\n';
+		CombinatorialThresholder::VerticalSumThresholdLargeReference(input.get(), maskB.get(), length, threshold);
+		Logger::Info << "Vertical, length " << length << ": " << watchB.ToString() << '\n';
 		
 #ifdef __SSE__
-		Mask2DPtr maskD = Mask2D::CreateCopy(artifacts.OriginalData().GetSingleMask());
+		Mask2DPtr maskD(new Mask2D(*artifacts.OriginalData().GetSingleMask()));
 		Stopwatch watchD(true);
-		ThresholdMitigater::VerticalSumThresholdLargeSSE(input, maskD, length, threshold);
-		AOLogger::Info << "SSE Vertical, length " << length << ": " << watchD.ToString() << '\n';
+		CombinatorialThresholder::VerticalSumThresholdLargeSSE(input.get(), maskD.get(), length, threshold);
+		Logger::Info << "SSE Vertical, length " << length << ": " << watchD.ToString() << '\n';
 #endif
 	}
 }
@@ -389,7 +391,7 @@ inline void DefaultStrategySpeedTest::TimeRankOperator::operator()()
 {
 	rfiStrategy::ArtifactSet artifacts(0);
 
-	rfiStrategy::Strategy *strategy = rfiStrategy::DefaultStrategy::CreateStrategy(
+	std::unique_ptr<rfiStrategy::Strategy> strategy = rfiStrategy::DefaultStrategy::CreateStrategy(
 		rfiStrategy::DefaultStrategy::GENERIC_TELESCOPE, rfiStrategy::DefaultStrategy::FLAG_NONE
 	);
 	prepareStrategy(artifacts);
@@ -397,19 +399,19 @@ inline void DefaultStrategySpeedTest::TimeRankOperator::operator()()
 	Stopwatch watch(true);
 	strategy->Perform(artifacts, progressListener);
 	watch.Pause();
-	delete strategy;
+	strategy.reset();
 	
-	Mask2DPtr input = Mask2D::CreateCopy(artifacts.ContaminatedData().GetSingleMask());
+	Mask2DPtr input(new Mask2D(*artifacts.ContaminatedData().GetSingleMask()));
 	
 	Stopwatch operatorTimer(true);
-	SIROperator::OperateHorizontally(input, 0.2);
-	SIROperator::OperateVertically(input, 0.2);
+	SIROperator::OperateHorizontally(input.get(), 0.2);
+	SIROperator::OperateVertically(input.get(), 0.2);
 	operatorTimer.Pause();
 	
 	long double operatorTime = operatorTimer.Seconds();
 	long double totalTime = watch.Seconds();
 	
-	AOLogger::Info
+	Logger::Info
 		<< "Rank operator took " << operatorTimer.ToShortString() << " (" << operatorTime << ")"
 		<< " of " << watch.ToShortString() << " (" << totalTime << ")"
 		<< ", " << ( operatorTime * 100.0 / totalTime) << "%\n";
@@ -418,89 +420,91 @@ inline void DefaultStrategySpeedTest::TimeRankOperator::operator()()
 #ifdef __SSE__
 inline void DefaultStrategySpeedTest::TimeSSEHighPassFilterStrategy::operator()()
 {
-	rfiStrategy::Strategy *strategy = new rfiStrategy::Strategy();
+	std::unique_ptr<rfiStrategy::Strategy> strategy(new rfiStrategy::Strategy());
 	rfiStrategy::ActionBlock &block = *strategy;
-	rfiStrategy::ActionBlock *current;
+	rfiStrategy::ActionBlock *current, *scratch;
 
-	block.Add(new rfiStrategy::SetFlaggingAction());
+	block.Add(std::unique_ptr<rfiStrategy::SetFlaggingAction>(new rfiStrategy::SetFlaggingAction()));
 
-	rfiStrategy::ForEachPolarisationBlock *fepBlock = new rfiStrategy::ForEachPolarisationBlock();
-	block.Add(fepBlock);
-	current = fepBlock;
+	std::unique_ptr<rfiStrategy::ForEachPolarisationBlock> fepBlock(new rfiStrategy::ForEachPolarisationBlock());
+	scratch = fepBlock.get();
+	block.Add(std::move(fepBlock));
+	current = scratch;
 
-	rfiStrategy::ForEachComplexComponentAction *focAction = new rfiStrategy::ForEachComplexComponentAction();
+	std::unique_ptr<rfiStrategy::ForEachComplexComponentAction> focAction(new rfiStrategy::ForEachComplexComponentAction());
 	focAction->SetOnAmplitude(true);
 	focAction->SetOnImaginary(false);
 	focAction->SetOnReal(false);
 	focAction->SetOnPhase(false);
 	focAction->SetRestoreFromAmplitude(false);
-	current->Add(focAction);
-	current = focAction;
+	rfiStrategy::ForEachComplexComponentAction *focActionPtr = focAction.get();
+	current->Add(std::move(focAction));
+	current = focActionPtr;
 
-	rfiStrategy::IterationBlock *iteration = new rfiStrategy::IterationBlock();
+	std::unique_ptr<rfiStrategy::IterationBlock> iteration(new rfiStrategy::IterationBlock());
 	iteration->SetIterationCount(2);
 	iteration->SetSensitivityStart(4.0);
-	current->Add(iteration);
-	current = iteration;
+	scratch = iteration.get();
+	current->Add(std::move(iteration));
+	current = scratch;
 	
-	rfiStrategy::SumThresholdAction *t2 = new rfiStrategy::SumThresholdAction();
+	std::unique_ptr<rfiStrategy::SumThresholdAction> t2(new rfiStrategy::SumThresholdAction());
 	t2->SetBaseSensitivity(1.0);
-	current->Add(t2);
+	current->Add(std::move(t2));
 
-	rfiStrategy::CombineFlagResults *cfr2 = new rfiStrategy::CombineFlagResults();
-	current->Add(cfr2);
+	std::unique_ptr<rfiStrategy::CombineFlagResults> cfr2(new rfiStrategy::CombineFlagResults());
+	current->Add(std::move(cfr2));
 
-	cfr2->Add(new rfiStrategy::FrequencySelectionAction());
-	cfr2->Add(new rfiStrategy::TimeSelectionAction());
+	cfr2->Add(std::unique_ptr<rfiStrategy::FrequencySelectionAction>(new rfiStrategy::FrequencySelectionAction()));
+	cfr2->Add(std::unique_ptr<rfiStrategy::TimeSelectionAction>(new rfiStrategy::TimeSelectionAction()));
 
-	current->Add(new rfiStrategy::SetImageAction());
-	rfiStrategy::ChangeResolutionAction
-		*changeResAction2 = new rfiStrategy::ChangeResolutionAction();
+	current->Add(std::unique_ptr<rfiStrategy::SetImageAction>(new rfiStrategy::SetImageAction()));
+	std::unique_ptr<rfiStrategy::ChangeResolutionAction>
+		changeResAction2(new rfiStrategy::ChangeResolutionAction());
 	changeResAction2->SetTimeDecreaseFactor(3);
 	changeResAction2->SetFrequencyDecreaseFactor(3);
 
-	rfiStrategy::HighPassFilterAction *hpAction = new rfiStrategy::HighPassFilterAction();
+	std::unique_ptr<rfiStrategy::HighPassFilterAction> hpAction(new rfiStrategy::HighPassFilterAction());
 	hpAction->SetHKernelSigmaSq(2.5);
 	hpAction->SetWindowWidth(10*2+1);
 	hpAction->SetVKernelSigmaSq(5.0);
 	hpAction->SetWindowHeight(15*2+1);
 	hpAction->SetMode(rfiStrategy::HighPassFilterAction::StoreRevised);
-	changeResAction2->Add(hpAction);
+	changeResAction2->Add(std::move(hpAction));
 
-	current->Add(changeResAction2);
+	current->Add(std::move(changeResAction2));
 
-	current = focAction;
-	rfiStrategy::SumThresholdAction *t3 = new rfiStrategy::SumThresholdAction();
-	current->Add(t3);
+	current = focActionPtr;
+	std::unique_ptr<rfiStrategy::SumThresholdAction> t3(new rfiStrategy::SumThresholdAction());
+	current->Add(std::move(t3));
 	
-	rfiStrategy::PlotAction *plotPolarizationStatistics = new rfiStrategy::PlotAction();
+	std::unique_ptr<rfiStrategy::PlotAction> plotPolarizationStatistics(new rfiStrategy::PlotAction());
 	plotPolarizationStatistics->SetPlotKind(rfiStrategy::PlotAction::PolarizationStatisticsPlot);
-	block.Add(plotPolarizationStatistics);
+	block.Add(std::move(plotPolarizationStatistics));
 	
-	rfiStrategy::SetFlaggingAction
-		*setFlagsInAllPolarizations = new rfiStrategy::SetFlaggingAction();
+	std::unique_ptr<rfiStrategy::SetFlaggingAction>
+		setFlagsInAllPolarizations(new rfiStrategy::SetFlaggingAction());
 	setFlagsInAllPolarizations->SetNewFlagging(rfiStrategy::SetFlaggingAction::PolarisationsEqual);
 	
-	block.Add(setFlagsInAllPolarizations);
-	block.Add(new rfiStrategy::StatisticalFlagAction());
-	block.Add(new rfiStrategy::TimeSelectionAction());
+	block.Add(std::move(setFlagsInAllPolarizations));
+	block.Add(std::unique_ptr<rfiStrategy::StatisticalFlagAction>(new rfiStrategy::StatisticalFlagAction()));
+	block.Add(std::unique_ptr<rfiStrategy::TimeSelectionAction>(new rfiStrategy::TimeSelectionAction()));
 
-	rfiStrategy::BaselineSelectionAction
-		*baselineSelection = new rfiStrategy::BaselineSelectionAction();
+	std::unique_ptr<rfiStrategy::BaselineSelectionAction>
+		baselineSelection(new rfiStrategy::BaselineSelectionAction());
 	baselineSelection->SetPreparationStep(true);
-	block.Add(baselineSelection);
+	block.Add(std::move(baselineSelection));
 
-	rfiStrategy::SetFlaggingAction *orWithOriginals = new rfiStrategy::SetFlaggingAction();
+	std::unique_ptr<rfiStrategy::SetFlaggingAction> orWithOriginals(new rfiStrategy::SetFlaggingAction());
 	orWithOriginals->SetNewFlagging(rfiStrategy::SetFlaggingAction::OrOriginal);
-	block.Add(orWithOriginals);
+	block.Add(std::move(orWithOriginals));
 
 	rfiStrategy::ArtifactSet artifacts(0);
 	prepareStrategy(artifacts);
 	DummyProgressListener progressListener;
 	Stopwatch watch(true);
 	strategy->Perform(artifacts, progressListener);
-	AOLogger::Info << "Default strategy took: " << watch.ToString() << '\n';
-	delete strategy;
+	Logger::Info << "Default strategy took: " << watch.ToString() << '\n';
 }
 #endif // __SSE__
 
